@@ -5,11 +5,6 @@
 # We merge the restored catalogues right here and copy the list of
 # packages to a place where the AM can find them.
 
-if [ ! $1 ]
-then
-  exit 0;
-fi
-
 if [ ! -e $1 ]
 then
   exit 0
@@ -21,7 +16,7 @@ upkgs="$HOME/.hildon-application-manager.backup"
 
 if grep -q "$cats" "$1"
 then
-  hildon-application-manager-config add "$cats"
+  sudo /usr/bin/hildon-application-manager-util restore-catalogues
 fi
 
 if grep -q "$pkgs" "$1"
