@@ -50,12 +50,14 @@
 
 #define _(x) gettext (x)
 
+#define HILDON_ENABLE_UNSTABLE_API 
+
 extern "C" {
-  #include "hildonbreadcrumbtrail.h"
   #include <hildon/hildon-window.h>
   #include <hildon/hildon-note.h>
   #include <libosso.h>
   #include <hildon/hildon-help.h>
+  #include <hildon/hildon-bread-crumb-trail.h>
 }
 
 using namespace std;
@@ -90,9 +92,17 @@ make_view_path (view *v)
     return g_list_append (make_view_path (v->parent), v);
 }
 
+static const gchar *
+get_view_label (GList *node)
+{
+  return gettext (((view *)node->data)->label);
+}
+
 void
 show_view (view *v)
 {
+  GList *p;
+
   if (cur_view)
     {
       gtk_container_remove(GTK_CONTAINER(main_vbox), cur_view);
@@ -110,8 +120,14 @@ show_view (view *v)
 
   g_list_free (cur_path);
   cur_path = make_view_path (v);
-  hildon_bread_crumb_trail_set_path (main_trail, cur_path);
-  
+
+  hildon_bread_crumb_trail_clear (HILDON_BREAD_CRUMB_TRAIL (main_trail));
+
+  for (p = cur_path; p != NULL; p = p->next)
+    hildon_bread_crumb_trail_push_text (HILDON_BREAD_CRUMB_TRAIL (main_trail),
+                                        get_view_label (p),
+                                        p, NULL);
+
   gtk_box_pack_start (GTK_BOX (main_vbox), cur_view, TRUE, TRUE, 10);
   gtk_widget_show(main_vbox);
 }
@@ -124,16 +140,10 @@ show_view_callback (GtkWidget *btn, gpointer data)
   show_view (v);
 }
 
-static const gchar *
-get_view_label (GList *node)
-{
-  return gettext (((view *)node->data)->label);
-}
-
 static void
-view_clicked (GList *node)
+view_clicked (HildonBreadCrumbTrail *bct, gpointer node, gpointer user_data)
 {
-  show_view ((view *)node->data);
+  show_view ((view *)((GList*)node)->data);
 }
 
 GtkWidget *make_main_view (view *v);
@@ -1317,7 +1327,7 @@ install_package_flow (package_info *pi)
   if (start_interaction_flow (GTK_WIDGET (get_main_window ())))
     {
       pi->ref ();
-      xxx_install_package (pi, install_package_flow_end, pi);
+      install_package (pi, install_package_flow_end, pi);
     }
 }
 
@@ -1371,7 +1381,7 @@ uninstall_package_flow (package_info *pi)
   if (start_interaction_flow (GTK_WIDGET (get_main_window ())))
     {
       pi->ref ();
-      xxx_uninstall_package (pi, uninstall_package_flow_end, pi);
+      uninstall_package (pi, uninstall_package_flow_end, pi);
     }
 }
 
@@ -1878,7 +1888,7 @@ install_named_package (int state, const char *package,
 	  g_free (text);
 	}
       else
-	xxx_install_package (pi, cont, data);
+	install_package (pi, cont, data);
 
       for (node = p->next; node != NULL; node = g_list_next (node))
 	{
@@ -1926,9 +1936,9 @@ install_named_packages (int state, const char **packages, int install_type,
       g_list_free (search_list);
     }
   
-  xxx_install_packages (package_list,
-			state, install_type,
-			cont, data);
+  install_packages (package_list,
+		    state, install_type,
+		    cont, data);
 }
 
 static GtkWidget *details_button;
@@ -2055,6 +2065,63 @@ rp_end (void *data)
   end_interaction_flow (GTK_WIDGET (get_main_window ()));
 }
 
+/* Updating all installed system-update packages
+ */
+
+static void us_get_system_packages (bool res, void *data);
+static void us_get_system_packages_reply (int cmd, apt_proto_decoder *dec,
+					  void *data);
+static void us_end (void *data);
+
+void
+update_system_flow ()
+{
+  if (start_interaction_flow (GTK_WIDGET (get_main_window ())))
+    refresh_package_cache_with_cont (APTSTATE_DEFAULT, FALSE,
+				     us_get_system_packages, NULL);
+}
+
+static void
+us_get_system_packages (bool res, void *data)
+{
+  apt_worker_get_system_update_packages (APTSTATE_DEFAULT,
+					 us_get_system_packages_reply,
+					 NULL);
+}
+
+static void
+us_get_system_packages_reply (int cmd, apt_proto_decoder *dec, void *data)
+{
+  char **packages = new char*[10];  // *cough*
+
+  if (dec == NULL)
+    {
+      us_end (data);
+      return;
+    }
+
+  int i = 0;
+  while (i < 10 && !dec->corrupted ())
+    {
+      char *name = dec->decode_string_dup ();
+      if (name == NULL)
+	break;
+
+      packages[i++] = name;
+    }
+  packages[i] = NULL;
+
+  install_named_packages (APTSTATE_DEFAULT,
+			  (const char**)packages, INSTALL_TYPE_UPDATE_SYSTEM,
+			  us_end, data);
+}
+
+static void
+us_end (void *data)
+{
+  end_interaction_flow (GTK_WIDGET (get_main_window ()));
+}
+
 /* Installing from file
  */
 
@@ -2077,8 +2144,8 @@ install_from_local_file (char *filename, void *unused)
 					 install_from_file_flow_end,
 					 filename);
       else
-	xxx_install_local_deb_file (filename,
-				    install_from_file_flow_end, filename);
+	install_local_deb_file (filename,
+				install_from_file_flow_end, filename);
     }
   else
     install_from_file_flow_end (filename);
@@ -2146,8 +2213,10 @@ mime_open_handler (gpointer raw_data, int argc, char **argv)
       const char *filename = argv[0];
 
       present_main_window ();
-      if (strcmp (filename, "backup.install") == 0)
+      if (strcmp (filename, "magic:restore-packages") == 0)
 	restore_packages_flow ();
+      if (strcmp (filename, "magic:update-system") == 0)
+	update_system_flow ();
       else
 	install_from_file_flow (filename);
     }
@@ -2494,10 +2563,11 @@ main (int argc, char **argv)
   main_vbox = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (window), main_vbox);
 
-  main_trail = hildon_bread_crumb_trail_new (get_view_label, view_clicked);
+  main_trail = hildon_bread_crumb_trail_new ();
+  g_signal_connect (G_OBJECT (main_trail), "crumb-clicked",
+                    G_CALLBACK (view_clicked), NULL);
+
   gtk_box_pack_start (GTK_BOX (main_vbox), main_trail, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (main_vbox), gtk_hseparator_new (), 
-		      FALSE, FALSE, 0);
 
   g_signal_connect (G_OBJECT (window), "destroy",
 		    G_CALLBACK (window_destroy), NULL);
