@@ -38,6 +38,7 @@
 #include "apt-worker-client.h"
 #include "util.h"
 #include "log.h"
+#include "confutils.h"
 
 #define _(x)       gettext (x)
 
@@ -193,6 +194,8 @@ set_catalogues_reply (int cmd, apt_proto_decoder *dec, void *data)
       c->cont (true, c->data);
       delete c;
     }
+
+  save_backup_data ();
 }
 
 static void
@@ -304,6 +307,8 @@ static void set_cat_list (cat_dialog_closure *c);
 static void
 cat_edit_response (GtkDialog *dialog, gint response, gpointer clos)
 {
+  bool should_ask_the_pill_question = false;
+
   cat_edit_closure *c = (cat_edit_closure *)clos;
 
   if (c->readonly)
@@ -349,13 +354,16 @@ cat_edit_response (GtkDialog *dialog, gint response, gpointer clos)
     {
       xexp_free (c->catalogue);
       if (!strcmp (gtk_entry_get_text (GTK_ENTRY (c->uri_entry)), "matrix"))
-	ask_the_pill_question ();
+	should_ask_the_pill_question = true;
     }
 
   delete c;
-
+ 
   pop_dialog_parent (GTK_WIDGET (dialog));
   gtk_widget_destroy (GTK_WIDGET (dialog));
+
+  if (should_ask_the_pill_question)
+    ask_the_pill_question ();
 }
 
 static void
@@ -856,29 +864,6 @@ static void add_catalogues_cont_3_enable (bool res, void *data);
 static void add_catalogues_cont_3 (bool res, bool enable, void *data);
 static void add_catalogues_cont_4 (bool res, void *data);
 
-static bool
-cats_are_equal (xexp *cat1, xexp *cat2)
-{
-  return (tokens_equal (xexp_aref_text (cat1, "uri"),
-			xexp_aref_text (cat2, "uri"))
-	  && tokens_equal (xexp_aref_text (cat1, "dist"),
-		       xexp_aref_text (cat2, "dist"))
-	  && tokens_equal (xexp_aref_text (cat1, "components"),
-			   xexp_aref_text (cat2, "components")));
-}
-
-static xexp *
-find_catalogue (xexp *catalogues, xexp *cat)
-{
-  for (xexp *c = xexp_first (catalogues); c; c = xexp_rest (c))
-    {
-      if (xexp_is (c, "catalogue") && cats_are_equal (c, cat))
-	return c;
-    }
-
-  return NULL;
-}
-
 static void
 add_catalogues_cont_3_add (bool res, void *data)
 {
