@@ -21,7 +21,6 @@
  *
  */
 
-#define DBUS_API_SUBJECT_TO_CHANGE
 #include <dbus/dbus.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
@@ -33,6 +32,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <errno.h>
+#include <sys/statvfs.h>
 
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
@@ -44,10 +44,6 @@
 #include <conic.h>
 #include <libgnomevfs/gnome-vfs.h>
 
-extern "C" {
-#include <obex-vfs-utils/ovu-xfer.h>
-}
-
 #include "util.h"
 #include "details.h"
 #include "log.h"
@@ -446,24 +442,28 @@ annoy_user_with_log (const gchar *text)
 }
 
 void
-annoy_user_with_errno (int err, const gchar *detail)
+annoy_user_with_errno (int err, const gchar *detail,
+		       void (*cont) (void *), void *data)
 {
   add_log ("%s: %s\n", detail, strerror (err));
 
+  const char *msg;
   if (err == ENAMETOOLONG)
-    annoy_user (dgettext ("hildon-common-strings",
-			  "file_ib_name_too_long"));
+    msg = dgettext ("hildon-common-strings",
+		    "file_ib_name_too_long");
   else if (err == EPERM || err == EACCES)
-    annoy_user (dgettext ("hildon-fm",
-			  "sfil_ib_saving_not_allowed"));
+    msg = dgettext ("hildon-fm",
+		    "sfil_ib_saving_not_allowed");
   else if (err == ENOENT)
-    annoy_user (dgettext ("hildon-common-strings",
-			  "sfil_ni_cannot_continue_target_folder_deleted"));
+    msg = dgettext ("hildon-common-strings",
+		    "sfil_ni_cannot_continue_target_folder_deleted");
   else if (err == ENOSPC)
-    annoy_user (dgettext ("hildon-common-strings",
-			  "sfil_ni_not_enough_memory"));
+    msg = dgettext ("hildon-common-strings",
+		    "sfil_ni_not_enough_memory");
   else
-    annoy_user (_("ai_ni_operation_failed"));
+    msg = _("ai_ni_operation_failed");
+  
+  annoy_user_with_cont (msg, cont, data);
 }
 
 void
@@ -988,6 +988,8 @@ global_name_func (GtkTreeViewColumn *column,
   if (!pi)
     return;
 
+  const char *name = pi->get_display_name (global_installed);
+
   if (gtk_tree_selection_iter_is_selected (selection, iter))
     {
       const gchar *desc;
@@ -1001,12 +1003,12 @@ global_name_func (GtkTreeViewColumn *column,
 	    desc = pi->installed_short_description;
 	}
       markup = g_markup_printf_escaped ("%s\n<small>%s</small>",
-					pi->name, desc);
+					name, desc);
       g_object_set (cell, "markup", markup, NULL);
       g_free (markup);
     }
   else
-    g_object_set (cell, "text", pi->name, NULL);
+    g_object_set (cell, "text", name, NULL);
 }
 
 static void
@@ -1470,7 +1472,8 @@ make_select_package_list_store (GList *package_list, gint *total_size)
       package_info *pi = (package_info *) node->data;
       GtkTreeIter iter;
       char package_size_str[20];
-      size_string_general (package_size_str, 20, pi->info.install_user_size_delta);
+      size_string_general (package_size_str, 20,
+			   pi->info.install_user_size_delta);
       gtk_list_store_append (list_store, &iter);
       gtk_list_store_set (list_store, &iter,
 			  COLUMN_SP_SELECTED, TRUE,
@@ -1693,9 +1696,9 @@ void select_package_list (GList *package_list,
 #define KILO 1000
 
 void
-size_string_general (char *buf, size_t n, int bytes)
+size_string_general (char *buf, size_t n, int64_t bytes)
 {
-  size_t num = bytes;
+  uint64_t num = bytes;
 
   if (num == 0)
     snprintf (buf, n, _("ai_li_size_max_99kb"), 0);
@@ -1707,7 +1710,7 @@ size_string_general (char *buf, size_t n, int bytes)
       // bytes ~ num * KILO
       num = (bytes + KILO/2) / KILO;
       if (num < 100)
-	snprintf (buf, n, _("ai_li_size_max_99kb"), num);
+	snprintf (buf, n, _("ai_li_size_max_99kb"), (int)num);
       else
 	{
 	  // round to nearest 100 KILO
@@ -1721,7 +1724,7 @@ size_string_general (char *buf, size_t n, int bytes)
 	      // bytes ~ num * KILO * KILO
 	      num = (bytes + KILO*KILO/2) / (KILO*KILO);
 	      if (num < KILO)
-		snprintf (buf, n, _("ai_li_size_10mb_1gb"), num);
+		snprintf (buf, n, _("ai_li_size_10mb_1gb"), (int)num);
 	      else
 		snprintf (buf, n, _("ai_li_size_larger_than_1gb"),
 			  ((float)num)/KILO);
@@ -1731,9 +1734,9 @@ size_string_general (char *buf, size_t n, int bytes)
 }
 
 void
-size_string_detailed (char *buf, size_t n, int bytes)
+size_string_detailed (char *buf, size_t n, int64_t bytes)
 {
-  size_t num = bytes;
+  uint64_t num = bytes;
 
   if (num == 0)
     snprintf (buf, n, _("ai_li_de_size_max_999kb"), 0);
@@ -1745,7 +1748,7 @@ size_string_detailed (char *buf, size_t n, int bytes)
       // bytes ~ num * KILO
       num = (bytes + KILO/2) / KILO;
       if (num < 1000)
-	snprintf (buf, n, _("ai_li_de_size_max_999kb"), num);
+	snprintf (buf, n, _("ai_li_de_size_max_999kb"), (int)num);
       else
 	{
 	  // round to nearest 10 KILO
@@ -2048,9 +2051,9 @@ copy_progress (GnomeVFSAsyncHandle *handle,
       if (stat (copy_target, &buf) < 0)
 	{
 	  /* If a obex connection is refused before the downloading is
-	     started, ovu_async_xfer seems to report success without
-	     actually creating the file.  We treat that situation as
-	     an I/O error.
+	     started, gnome_vfs_async_xfer seems to report success
+	     without actually creating the file.  We treat that
+	     situation as an I/O error.
 	  */
 	  call_copy_cont (GNOME_VFS_ERROR_IO);
 	}
@@ -2103,17 +2106,17 @@ do_copy (const char *source, GnomeVFSURI *source_uri,
   show_progress (dgettext ("hildon-fm",
 			   "docm_nw_opening_file"));
 
-  result = ovu_async_xfer (&handle,
-			   source_uri_list,
-			   target_uri_list,
-			   GNOME_VFS_XFER_DEFAULT,
-			   GNOME_VFS_XFER_ERROR_MODE_QUERY,
-			   GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
-			   GNOME_VFS_PRIORITY_DEFAULT,
-			   copy_progress,
-			   NULL,
-			   NULL,
-			   NULL);
+  result = gnome_vfs_async_xfer (&handle,
+				 source_uri_list,
+				 target_uri_list,
+				 GNOME_VFS_XFER_DEFAULT,
+				 GNOME_VFS_XFER_ERROR_MODE_QUERY,
+				 GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
+				 GNOME_VFS_PRIORITY_DEFAULT,
+				 copy_progress,
+				 NULL,
+				 NULL,
+				 NULL);
 
   if (result != GNOME_VFS_OK)
     call_copy_cont (result);
@@ -2312,46 +2315,6 @@ all_whitespace (const char *str)
   return (*skip_whitespace (str)) == '\0';
 }
 
-  /* NULL and empty strings are considered equal.  Whitespace at the
-     beginning and end is ignored.  Sequences of white spaces are
-     equal to every other sequence of white space.
-  */
-
-bool
-tokens_equal (const char *str1, const char *str2)
-{
-  if (str1 == NULL)
-    str1 = "";
-
-  if (str2 == NULL)
-    str2 = "";
-
-  str1 = skip_whitespace (str1);
-  str2 = skip_whitespace (str2);
-
-  while (*str1 && *str2)
-    {
-      if (isspace (*str1) && isspace (*str2))
-	{
-	  str1 = skip_whitespace (str1);
-	  str2 = skip_whitespace (str2);
-	}
-      else if (*str1 == *str2)
-	{
-	  str1++;
-	  str2++;
-	}
-      else
-	break;
-    }
-  
-  str1 = skip_whitespace (str1);
-  str2 = skip_whitespace (str2);
-
-  return *str1 == '\0' && *str2 == '\0';
-}
-
-
 static ConIcConnection *connection_object = NULL;
 
 struct en_closure {
@@ -2736,3 +2699,15 @@ grab_focus_on_map (GtkWidget *widget)
   g_signal_connect (widget, "map", G_CALLBACK (grab_focus), NULL);
 }
 
+int64_t
+get_free_space ()
+{
+  struct statvfs buf;
+
+  if (statvfs("/", &buf) != 0)
+    return -1;
+  
+  int64_t res = (int64_t)buf.f_bfree * (int64_t)buf.f_bsize;
+  printf ("FREE: %Ld\n", res);
+  return res;
+}
